@@ -1,5 +1,7 @@
 """``runway gen-sample`` command group."""
 # docs: file://./../../../../docs/source/commands.rst
+from typing import Any
+
 import click
 
 from ... import options
@@ -9,10 +11,10 @@ from ._cdk_tsc import cdk_tsc
 from ._cfn import cfn
 from ._cfngin import cfngin
 from ._k8s_cfn_repo import k8s_cfn_repo
+from ._k8s_flux_repo import k8s_flux_repo
 from ._k8s_tf_repo import k8s_tf_repo
 from ._sls_py import sls_py
 from ._sls_tsc import sls_tsc
-from ._stacker import stacker
 from ._static_angular import static_angular
 from ._static_react import static_react
 from ._tf import tf
@@ -25,9 +27,9 @@ __all__ = [
     "cfngin",
     "k8s_cfn_repo",
     "k8s_tf_repo",
+    "k8s_flux_repo",
     "sls_py",
     "sls_tsc",
-    "stacker",
     "static_angular",
     "static_react",
     "tf",
@@ -41,9 +43,9 @@ COMMANDS = [
     cfngin,
     k8s_cfn_repo,
     k8s_tf_repo,
+    k8s_flux_repo,
     sls_py,
     sls_tsc,
-    stacker,
     static_angular,
     static_react,
     tf,
@@ -54,7 +56,7 @@ COMMANDS = [
 @options.debug
 @options.no_color
 @options.verbose
-def gen_sample(**_):
+def gen_sample(**_: Any) -> None:
     """Generate a sample Runway module module/project.
 
     The sample is created in the current directory.
