@@ -1,7 +1,7 @@
 """Install a version of kubectl."""
 # docs: file://./../../../../docs/source/commands.rst
 import logging
-from typing import Any  # pylint: disable=W
+from typing import Any
 
 import click
 
@@ -16,13 +16,12 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.debug
 @options.no_color
 @options.verbose
-def install(version, **_):
-    # type: (str, Any) -> None
+def install(version: str, **_: Any) -> None:
     """Install the specified <version> of kubectl (e.g. v1.14.0).
 
     If no version is specified, Runway will attempt to find and read a
-    ".kubectl-version" file in the current directory. If this file doesn't
-    exist, nothing will be installed.
+    ".kubectl-version" file in the current directory.
+    If this file doesn't exist, nothing will be installed.
 
     Compatible with https://github.com/alexppg/kbenv.
 
