@@ -5,6 +5,8 @@ from __future__ import annotations
 import re
 from typing import TYPE_CHECKING, Any, NamedTuple, Set
 
+from typing_extensions import Final, Literal
+
 from ....lookups.handlers.base import LookupHandler
 from ...exceptions import StackDoesNotExist
 
@@ -12,8 +14,6 @@ if TYPE_CHECKING:
     from ....context import CfnginContext
     from ....variables import VariableValue
 
-TYPE_NAME = "output"
-
 
 class OutputQuery(NamedTuple):
     """Output query NamedTuple."""
@@ -25,6 +25,9 @@ class OutputQuery(NamedTuple):
 class OutputLookup(LookupHandler):
     """AWS CloudFormation Output lookup."""
 
+    TYPE_NAME: Final[Literal["output"]] = "output"
+    """Name that the Lookup is registered as."""
+
     @classmethod
     def handle(  # pylint: disable=arguments-differ
         cls, value: str, context: CfnginContext, **_: Any
