@@ -8,6 +8,7 @@ from typing import TYPE_CHECKING, Any, List, Optional, Union
 from botocore.exceptions import ClientError
 
 from .....compat import cached_property
+from .....mixins import DelCachedPropMixin
 from .._response import BaseResponse
 from ._sync_handler import S3SyncHandler
 
@@ -24,7 +25,7 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__.replace("._", "."))
 
 
-class Bucket:
+class Bucket(DelCachedPropMixin):
     """AWS S3 bucket."""
 
     def __init__(
@@ -52,14 +53,10 @@ class Bucket:
 
     @property
     def exists(self) -> bool:
-        """Check whether the bucket exists.
+        """Check whether the bucket exists and is accessible."""
+        return not self.forbidden and not self.not_found
 
-        Opposite of not_found.
-
-        """
-        return not self.not_found
-
-    @cached_property
+    @property
     def forbidden(self) -> bool:
         """Check whether access to the bucket is forbidden."""
         return self.head.metadata.forbidden
@@ -82,9 +79,9 @@ class Bucket:
                 self.name,
                 exc_info=True,
             )
-            return BaseResponse(**err.response)
+            return BaseResponse.parse_obj(err.response)
 
-    @cached_property
+    @property
     def not_found(self) -> bool:
         """Check whether the bucket exists."""
         return self.head.metadata.not_found
@@ -119,9 +116,7 @@ class Bucket:
                 {"LocationConstraint": self.client.meta.region_name}
             )
         LOGGER.debug("creating bucket: %s", json.dumps(kwargs))
-        del self.not_found  # clear cached value
-        del self.forbidden  # clear cached value
-        del self.head  # clear cached value
+        self._del_cached_property("head")
         return self.client.create_bucket(**kwargs)
 
     def enable_versioning(self) -> None:
@@ -240,3 +235,7 @@ class Bucket:
             session=self.session,
             src=self.format_bucket_path_uri(prefix=prefix),
         ).run()
+
+    def __bool__(self) -> bool:
+        """Implement evaluation of instances as a bool."""
+        return self.exists
